Trait ratframe::NewCC

source ·
pub trait NewCC {
    // Required method
    fn new(cc: &CreationContext<'_>) -> Self;

    // Provided method
    fn canvas_id() -> String { ... }
}
Implement this trait when you want to setup ratatui to use custom fonts Otherwise it will use the default egui font which is missing extra unicode characters .Implement canvas_id() for a custom canvas id

Required Methods

source

fn new(cc: &CreationContext<'_>) -> Self

Provided Methods

source

fn canvas_id() -> String

set this to the same canvas id as in the index.html

Object Safety

This trait is not object safe.

Implementors