pub trait NewCC {
// Required method
fn new(cc: &CreationContext<'_>) -> Self;
// Provided method
fn canvas_id() -> String { ... }
}Expand description
Implement this trait when you want to setup ratatui to use custom fonts Otherwise it will use the default egui font which is missing extra unicode characters .Implement canvas_id() for a custom canvas id
Required Methods
fn new(cc: &CreationContext<'_>) -> Self
Provided Methods
Object Safety
This trait is not object safe.